
`fracridge` : Ridge regression with fraction regularization
============================================================

This software automatically finds regularization metaparameters for ridge
regression


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   auto_examples/index.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


